# cstock_python
Must function with python 3.11 to be compatible with Hou and other apps

[![Python application](https://github.com/Ceonsamea/cstock_python/actions/workflows/python-app.yml/badge.svg?branch=main)](https://github.com/Ceonsamea/cstock_python/actions/workflows/python-app.yml)
